package com.cultural.heritage.model.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.baomidou.mybatisplus.extension.handlers.JacksonTypeHandler;
import com.cultural.heritage.model.dto.snapshot.GoodSnapshot;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;

import java.io.Serial;
import java.io.Serializable;

/**
 * 订单明细
 * @TableName   order_item
 */
@Data
@TableName(value = "order_item", autoResultMap = true)
@Schema(description = "订单明细", requiredProperties = {"id", "orderId", "goodSnapshot", "priceSnapshot", "quantity", "itemTotalAmount"})
public class OrderItems implements Serializable {

    /**
     * 订单明细id
     */
    @TableId(type = IdType.AUTO)
    @Schema(description = "订单明细id(id > 0)", example = "2")
    private Long id;


    /**
     * 关联的订单id
     */
    @Schema(description = "关联的订单id(id > 0)", example = "3")
    private Long orderId;


    /**
     * 商品信息快照
     */
    @TableField(typeHandler = JacksonTypeHandler.class)
    private GoodSnapshot goodSnapshot;


    /**
     * 商品单价快照
     */
    @Schema(description = "商品单价", example = "15.00")
    private Double priceSnapshot;


    /**
     * 购买数量
     */
    @Schema(description = "购买数量", example = "30")
    private Integer quantity;


    /**
     * 订单项金额（单价 * 数量）
     */
    @Schema(description = "订单项金额(单价 * 数量)", example = "55.00")
    private Double itemTotalAmount;

    /**
     * 预约日期
     */
    @Schema(description = "预约日期", example = "2024-11-09")
    private String reservationDate;


    /**
     * 预约的具体时间段
     */
    @Schema(description = "预约的具体时间段", example = "8:00-12:00")
    private String timeSlot;


    @Serial
    private static final long serialVersionUID = 1L;
}
